@@ -25,15 +25,13 @@ public:
   
   virtual void update(double time,
                       uint32_t* out,
-		              const uint32_t* in,
-		              const uint32_t* in2,
-		              const uint32_t* in3)
+                      const uint32_t* in)
   {
     unsigned int* reusable = 0;
     // remove old frames
     for (std::list< std::pair< double, unsigned int* > >::iterator i=buffer.begin(); i != buffer.end(); ++i)
       {
-	if (i->first < (time - delay))
+	if (i->first < (time - delay) || i->first >= time)
 	  {
 	    // remove me
 	    if (reusable != 0)
@@ -71,7 +69,7 @@ public:
   }
   
 private:
-  f0r_param_double delay;
+  double delay;
   std::list< std::pair< double, unsigned int* > > buffer;
 };
 
