@@ -950,8 +950,6 @@ p->dit=p->dit+256*p->dmax;
 void f0r_get_param_value(f0r_instance_t instance, f0r_param_t param, int param_index)
 {
 inst *p;
-double tmpf;
-int tmpi;
 
 p=(inst*)instance;
 
@@ -1027,9 +1025,6 @@ switch(param_index)
 void f0r_update(f0r_instance_t instance, double time, const uint32_t* inframe, uint32_t* outframe)
 {
 inst *in;
-float l;
-unsigned char lc;
-int i;
 
 assert(instance);
 in=(inst*)instance;
